@@ -1,15 +1,9 @@
-#
-# Catlyst::Action::SerializeBase.pm
-# Created by: Adam Jacob, Marchex, <adam@hjksolutions.com>
-#
-# $Id$
-
 package Catalyst::Action::SerializeBase;
 
-use strict;
-use warnings;
+use Moose;
+use namespace::autoclean;
 
-use base 'Catalyst::Action';
+extends 'Catalyst::Action';
 use Module::Pluggable::Object;
 use Catalyst::Request::REST;
 use Catalyst::Utils ();
