@@ -1,12 +1,11 @@
-
 package Test::Serialize;
 
 use FindBin;
 
 use lib ("$FindBin::Bin/../lib");
 
-use strict;
-use warnings;
+use Moose;
+use namespace::autoclean;
 
 use Catalyst::Runtime '5.70';
 
